@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.0.5.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -180,7 +180,7 @@ extern int _xkbcommon_debug;
 
 union YYSTYPE
 {
-#line 162 "/home/ran/src/libxkbcommon/autotools-build/../src/xkbcomp/parser.y" /* yacc.c:1909  */
+#line 162 "src/xkbcomp/parser.y" /* yacc.c:1910  */
 
         int              ival;
         int64_t          num;
@@ -206,7 +206,7 @@ union YYSTYPE
         void            *geom;
         XkbFile         *file;
 
-#line 210 "src/xkbcomp/parser.h" /* yacc.c:1909  */
+#line 210 "src/xkbcomp/parser.h" /* yacc.c:1910  */
 };
 
 typedef union YYSTYPE YYSTYPE;
